@@ -1,13 +1,10 @@
 import csv
 import json
 import logging
-import time
-from datetime import datetime
 
 import ccxt
 import pandas as pd
 from ccxt.base.exchange import Exchange
-from notecoin.base.database import TradeData
 from tqdm import tqdm
 
 logger = logging.getLogger()
@@ -33,14 +30,14 @@ class LoadData:
         for sym in pbr:
             if ':' not in sym:
                 pbr.set_description(sym)
-                self.load(sym, *args, **kwargs)
+                self.load(sym, pbr, *args, **kwargs)
         self.write_data([], False)
         self.load_close()
 
     def load_close(self):
         pass
 
-    def load(self, symbol, *args, **kwargs):
+    def load(self, symbol, pbr, *args, **kwargs):
         pass
 
     def write_data(self, data_list, cache=True):
@@ -52,6 +49,7 @@ class LoadData:
         df = pd.DataFrame(self.cache_data)
         df = df[(df['timestamp'] >= self.unix_start) & (df['timestamp'] <= self.unix_end)]
         self._write(json.loads(df.to_json(orient='records')))
+        self.cache_data.clear()
 
     def _write(self, data_list):
         pass
@@ -67,7 +65,7 @@ class LoadDataKline(LoadData):
     def _write(self, data_list):
         self.csv_writer.writerows(data_list)
 
-    def load(self, symbol, *args, **kwargs):
+    def load(self, symbol, pbr, *args, **kwargs):
         unix_temp = self.unix_start
         for _ in range(1000):
             if unix_temp >= self.unix_end:
@@ -81,7 +79,7 @@ class LoadDataKline(LoadData):
                 df = pd.DataFrame(result, columns=['timestamp', 'open', 'close', 'low', 'high', 'vol'])
                 df['symbol'] = symbol
                 self.write_data(json.loads(df.to_json(orient='records')))
-                #time.sleep(int(self.exchange.rateLimit / 1000))
+                # time.sleep(int(self.exchange.rateLimit / 1000))
             except Exception as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
@@ -92,6 +90,7 @@ class LoadTradeKline(LoadData):
         super(LoadTradeKline, self).__init__(*args, **kwargs)
         self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
                                          fieldnames=["symbol", "id", "timestamp", "type", "side", "price", "amount"])
+        self.csv_writer.writeheader()
         # self.table = TradeData(prefix=self.exchange.name,
         #                       suffix=datetime.utcfromtimestamp(self.unix_start / 1000).strftime('%Y%m%d'))
 
@@ -103,10 +102,11 @@ class LoadTradeKline(LoadData):
         # self.table.insert(values=data_list)
         self.csv_writer.writerows(data_list)
 
-    def load(self, symbol, *args, **kwargs):
+    def load(self, symbol, pbr, *args, **kwargs):
         unix_temp = self.unix_start
         previous_trade_id = None
         for _ in range(1000):
+            pbr.set_description(f'{symbol}-{unix_temp}')
             if unix_temp >= self.unix_end:
                 break
             try:
@@ -132,7 +132,7 @@ class LoadTradeKline(LoadData):
                 } for trade in trades]
 
                 self.write_data(result)
-                #time.sleep(int(self.exchange.rateLimit / 1000))
+                # time.sleep(int(self.exchange.rateLimit / 1000))
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
                 self.exchange.sleep(10000)
